@@ -472,6 +472,18 @@ c_type bonobo_config_get_##name##_with_default (Bonobo_ConfigDatabase  db,    \
 MAKE_GET_SIMPLE (gchar *, NULL, string, TC_string, 
 		 g_strdup (*(char **)value->_value));
 
+/**
+ * bonobo_config_get_string_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a string from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (gchar *, string, g_strdup);
 
 /**
@@ -486,6 +498,18 @@ MAKE_GET_WITH_DEFAULT (gchar *, string, g_strdup);
  */
 MAKE_GET_SIMPLE (gint16, 0, short, TC_short, (*(gint16 *)value->_value));
 
+/**
+ * bonobo_config_get_short_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a 16 bit integer from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (gint16, short, );
 
 /**
@@ -500,6 +524,18 @@ MAKE_GET_WITH_DEFAULT (gint16, short, );
  */
 MAKE_GET_SIMPLE (guint16, 0, ushort, TC_ushort, (*(guint16 *)value->_value));
 
+/**
+ * bonobo_config_get_ushort_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a 16 bit unsigned integer from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (guint16, ushort, );
 
 /**
@@ -514,6 +550,18 @@ MAKE_GET_WITH_DEFAULT (guint16, ushort, );
  */
 MAKE_GET_SIMPLE (gint32, 0, long, TC_long, (*(gint32 *)value->_value));
 
+/**
+ * bonobo_config_get_long_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a 32 bit integer from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (gint32, long, );
 
 /**
@@ -528,6 +576,18 @@ MAKE_GET_WITH_DEFAULT (gint32, long, );
  */
 MAKE_GET_SIMPLE (guint32, 0, ulong, TC_ulong, (*(guint32 *)value->_value));
 
+/**
+ * bonobo_config_get_ulong_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a 32 bit unsigned integer from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (guint32, ulong, );
 
 /**
@@ -542,6 +602,18 @@ MAKE_GET_WITH_DEFAULT (guint32, ulong, );
  */
 MAKE_GET_SIMPLE (gfloat, 0.0, float, TC_float, (*(gfloat *)value->_value));
 
+/**
+ * bonobo_config_get_float_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a single precision floating point value from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (gfloat, float, );
 
 /**
@@ -556,6 +628,18 @@ MAKE_GET_WITH_DEFAULT (gfloat, float, );
  */
 MAKE_GET_SIMPLE (gdouble, 0.0, double, TC_double, (*(gdouble *)value->_value));
 
+/**
+ * bonobo_config_get_double_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a double precision floating point value from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (gdouble, double, );
 
 /**
@@ -570,6 +654,18 @@ MAKE_GET_WITH_DEFAULT (gdouble, double, );
  */
 MAKE_GET_SIMPLE (gchar, '\0', char, TC_char, (*(gchar *)value->_value));
 
+/**
+ * bonobo_config_get_char_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a 8 bit character value from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (gchar, char, );
 
 /**
@@ -585,6 +681,18 @@ MAKE_GET_WITH_DEFAULT (gchar, char, );
 MAKE_GET_SIMPLE (gboolean, FALSE, boolean, TC_boolean, 
 		 (*(CORBA_boolean *)value->_value));
 
+/**
+ * bonobo_config_get_boolean_with_default:
+ * @db: a reference to the database object
+ * @key: key of the value to get
+ * @defval: the default value
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned
+ *
+ * Get a boolean value from the configuration database
+ *
+ * Returns: the value contained in the database, or @defval on error.
+ */
 MAKE_GET_WITH_DEFAULT (gboolean, boolean, );
 
 /**
@@ -654,7 +762,7 @@ bonobo_config_get_value  (Bonobo_ConfigDatabase  db,
 	return retval;
 }
 
-#define MAKE_SET_SIMPLE(c_type, name, corba_tc)                               \
+#define MAKE_SET_SIMPLE(c_type, name, corba_type, corba_tc)                   \
 void bonobo_config_set_##name (Bonobo_ConfigDatabase  db,                     \
 			       const char            *key,                    \
 			       const c_type           value,                  \
@@ -664,7 +772,7 @@ void bonobo_config_set_##name (Bonobo_ConfigDatabase  db,                     \
 	bonobo_return_if_fail (db != CORBA_OBJECT_NIL, opt_ev);               \
 	bonobo_return_if_fail (key != NULL, opt_ev);                          \
 	any = bonobo_arg_new (corba_tc);                                      \
-	*((c_type *)(any->_value)) = value;                                   \
+	*((corba_type *)(any->_value)) = value;                               \
 	bonobo_config_set_value (db, key, any, opt_ev);                       \
 	bonobo_arg_release (any);                                             \
 }
@@ -678,7 +786,7 @@ void bonobo_config_set_##name (Bonobo_ConfigDatabase  db,                     \
  *
  * Set a 16 bit integer value in the configuration database.
  */
-MAKE_SET_SIMPLE (gint16, short, TC_short)
+MAKE_SET_SIMPLE (gint16, short, CORBA_short, TC_short)
 /**
  * bonobo_config_set_ushort:
  * @db: a reference to the database object
@@ -688,7 +796,7 @@ MAKE_SET_SIMPLE (gint16, short, TC_short)
  *
  * Set a 16 bit unsigned integer value in the configuration database.
  */
-MAKE_SET_SIMPLE (guint16, ushort, TC_ushort)
+MAKE_SET_SIMPLE (guint16, ushort, CORBA_unsigned_short, TC_ushort)
 /**
  * bonobo_config_set_long:
  * @db: a reference to the database object
@@ -698,7 +806,7 @@ MAKE_SET_SIMPLE (guint16, ushort, TC_ushort)
  *
  * Set a 32 bit integer value in the configuration database.
  */
-MAKE_SET_SIMPLE (gint32, long, TC_long)
+MAKE_SET_SIMPLE (gint32, long, CORBA_long, TC_long)
 /**
  * bonobo_config_set_ulong:
  * @db: a reference to the database object
@@ -708,7 +816,7 @@ MAKE_SET_SIMPLE (gint32, long, TC_long)
  *
  * Set a 32 bit unsigned integer value in the configuration database.
  */
-MAKE_SET_SIMPLE (guint32, ulong, TC_ulong)
+MAKE_SET_SIMPLE (guint32, ulong, CORBA_unsigned_long, TC_ulong)
 /**
  * bonobo_config_set_float:
  * @db: a reference to the database object
@@ -718,7 +826,7 @@ MAKE_SET_SIMPLE (guint32, ulong, TC_ulong)
  *
  * Set a single precision floating point value in the configuration database.
  */
-MAKE_SET_SIMPLE (gfloat, float, TC_float)
+MAKE_SET_SIMPLE (gfloat, float, CORBA_float, TC_float)
 /**
  * bonobo_config_set_double:
  * @db: a reference to the database object
@@ -728,7 +836,7 @@ MAKE_SET_SIMPLE (gfloat, float, TC_float)
  *
  * Set a double precision floating point value in the configuration database.
  */
-MAKE_SET_SIMPLE (gdouble, double, TC_double)
+MAKE_SET_SIMPLE (gdouble, double, CORBA_double, TC_double)
 /**
  * bonobo_config_set_boolean:
  * @db: a reference to the database object
@@ -738,7 +846,8 @@ MAKE_SET_SIMPLE (gdouble, double, TC_double)
  *
  * Set a boolean value in the configuration database.
  */
-MAKE_SET_SIMPLE (gboolean, boolean, TC_boolean)
+MAKE_SET_SIMPLE (gboolean, boolean, CORBA_boolean, TC_boolean)
+
 /**
  * bonobo_config_set_char:
  * @db: a reference to the database object
@@ -748,7 +857,7 @@ MAKE_SET_SIMPLE (gboolean, boolean, TC_boolean)
  *
  * Set a 8 bit characte value in the configuration database.
  */
-MAKE_SET_SIMPLE (gchar, char, TC_char)
+MAKE_SET_SIMPLE (gchar, char, CORBA_char, TC_char)
 /**
  * bonobo_config_set_string:
  * @db: a reference to the database object
@@ -811,4 +920,3 @@ bonobo_config_set_value  (Bonobo_ConfigDatabase  db,
 	if (!opt_ev)
 		CORBA_exception_free (&ev);
 }
-
